function ATR_compare_completed(app)
    clc
    %if strcmp(app.ModelchosenEditField_3.Value,'Completed')
        %%% PROJECT DATA %%%
        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Air specific gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]

        %%% ENGINE DATA %%%
        %T0_3 = 2000;                                                 % Temperature after combustion [K]
        OPR = app.RamjetOPREditField.Value;                                                    % Overall Pressure Ratio
        %mdot_0 = 284;                                               % Inlet mass flow rate [kg/s]
        epsilon_d = 0.98;                                                     % Stagnation pressure ratio for inlet
        epsilon_b = 0.95;                                                     % Stagnation pressure ratio for combustor
        epsilon_n = 0.98;                                                     % Stagnation pressure ratio for nozzle
        eta_c = 0.7;                                                % Compressor efficiency
        eta_t = 0.9;                                                    % Combustor turbine efficiency
        eta_b = 0.95;                                                   % Combustion efficiency
        %eta_n = 0.98;                                                   % Nozzle efficiency
        A_t = 17.4;                                               % Throat area [m^2]
        A_e = app.ExitAream2EditField.Value;                                               % Exit area [m^2]

        % Inlet area [m^2]
        A_0 = app.IntakeAream2EditField.Value;

        %%% AIR AND FUEL DATA FROM "HYPERSONIC AIRBREATHING PROPULSION"%%%
        c_p1 = 1900;                                               % Combusted gases specific heat [J/(kg*K)]
        c_p = 1004;                                                % Air specific heat [J/(kg*K)]
        gamma1 = 1.33;                                             % Combusted gases adiabatic expansion coefficient
        gamma = 1.4;                                               % Air adiabatic expansion coefficient
        H_i = 120900000; 
        % COMBUSTION DATA %
        T_prop = 95;                                               % Injection temperature [K]
        p_prop = 370000;                                           % Combustion chamber pressure [Pa]
        beta_c_prop = app.FuelCompressorRatioEditField.Value;                                             % Fuel compressor ratio
        gamma_comb = 1.4;                                          % Propellant adiabatic expansion coefficient
        c_p_comb = 14435;                                           % Hydrogen specific heat [J/(kg*K)]
        R_g = 4125.5;                                              % Specific gas constant for hydrogen [J/(kg*K)]
        w=1;
        T0_3_old = 0;

        for M_0=0.5:0.5:4
            i=1;
            for z=0:1500:25000                                              % Altitude [m]
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end                                                                                      % Heats of reaction  [J/kg]

                a_0 = sqrt(gamma * R * T_0);                            % Sound speed
                u = a_0 * M_0;                                          % Flight speed

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                mdot_0 = A_0 * u * ro_0;

                %%% PROCESSING %%%

                % Parameters after inlet
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Parameters after compressor
                T0_2 = T0_1 * (1 + 1/eta_c * (OPR^((gamma - 1)/gamma)-1));
                p0_2 = OPR * p0_1;

                % Fuel stechiometric ratio
                f = app.AirfuelratioEditField.Value;
                % Fuel ratio
                %f = (c_p1 * (T0_3 - T0_2)) / (eta_b * H_i - c_p1 * (T0_3 - T0_2));
                % Air-fuel ratio
                alpha = 1/f;

                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % First approximation of temperature after combustion
                if T0_3_old == 0    
                    T0_3_old = T0_2 + eta_b*f*(H_i/c_p1);
                end

                % Propellant after compression
                p_c_comb = beta_c_prop * p_prop;
                T_c_comb = T_prop * (1 + 1/eta_c * (beta_c_prop^((gamma_comb - 1)/gamma_comb)-1));

                % Expansion Ratio of combustor turbine
                beta_t_comb = p_c_comb/p0_2;

                % Propellant after expansion
                %T_t_comb = T_c_comb;
                T_t_comb = T0_3_old - c_p/c_p1 * 1/eta_t * ((T_c_comb - T_prop)/(1 + f));
                p_t_comb = p_c_comb / beta_t_comb;

                % Mixer 
                p0_21 = p_t_comb;
                T0_21 = (mdot_0*c_p*T0_2 + mdot_b*c_p_comb*T_t_comb)/(c_p1*(mdot_0 + mdot_b));

                % Parameters after combustor
                T0_3 = T0_21 + eta_b*f*(H_i/c_p1);
                p0_3 = epsilon_b * p0_21;

                % Parameters after turbine
                T0_4 = T0_3;
                p0_4 = epsilon_n * p0_3;

        %         M_x = 0.5;
        %         for M_x=0.2:0.1:3
        %             sol = 1/M_x * ((1 + (gamma1-1)/2 * M_x^2)/((gamma1 + 1)/2))^((gamma1+1)/(2*(gamma1-1)));
        %             geom = A_e/A_t;
        %             if abs(sol - geom)<=0.1
        %                 M_e = M_x;
        %             end
        %         end
        %         
        %         T_e = T0_4/(1 + (gamma1-1)/2 * M_e);
        %         p_e_id = (p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1)))/(1+(gamma1 - 1)/2 * M_e^(2))^(gamma1/(gamma1 - 1));
        %         p_e = p_e_id * epsilon_n * eta_b * epsilon_d;
        %         
        %         % Outflow rate
        %         w_e = M_e * sqrt(gamma1*R*T_e);
        %         

                % Outflow rate
                w_e = sqrt(2 * c_p1 * T0_4 * (1 - ((p_0 / (epsilon_n * p0_4))^((gamma1 - 1)/gamma1)))); 

                %%% Thrust
                T = (mdot_0 + mdot_b) * w_e - mdot_0 * u;
                %T = (mdot_0 + mdot_b) * w_e - mdot_0 * u + A_e * (p_e - p_0);
                if T<0
                    T=0;
                end

                %%% Specific Thrust
                I_a = (1 + f) * w_e - u;

                %%% Thrust
                %T = I_a * mdot_0;

                %%% Thermal Efficiency
                eta_th = 1 - 1 / (1 + (gamma - 1)/2 * M_0^2);
                %%% Propulsive Efficiency
                eta_p = 2 / (sqrt(T0_3 / (T_0 * (1 + (gamma - 1)/2 * M_0^2))) + 1);

                %%% Thrust Specific Fuel Consumption
                I_sp = (I_a + 2 * u) / (2 * eta_th * H_i);

                TIT_z(w,i)= T0_3;
                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                z_z(w,i) = z;

                T0_3_old = T0_3;
                i = i+1;
            end
            w = w+1;
        end
        %if strcmp(app.PlotDropDown.Value,'Thrust')
        cla(app.UIAxes3_4)
        for j=1:1:w-1
            plot(app.UIAxes3_4,z_z(j,:),T_z(j,:));
            hold(app.UIAxes3_4,'on'); 
        end
        title(app.UIAxes3_4,'Completed');
        legend(app.UIAxes3_4,'M=0.5','M=1','M=1.5','M=2','M=2.5','M=3','M=3.5','M=4');
        xlabel(app.UIAxes3_4,'z [m]');
        ylabel(app.UIAxes3_4,'T [N]');
        %end        
    %end
end