function ATR_compare_ramjet_compressor_known(app)

    %if strcmp(app.ModelchosenEditField_3.Value,'Ramjet + Compressor (TIT known)')

        %%% PROJECT DATA %%%
        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]

        %%% ENGINE DATA %%%
        T0_3 = app.TurbineInletTemperatureKEditField_6.Value;                                                  % Temperature after combustion [K]
        OPR = app.RamjetOPREditField.Value;                                                    % Overall Pressure Ratio
        epsilon_d = 0.9;                                                 % Stagnation pressure ratio for inlet
        epsilon_b = 0.95;                                                     % Stagnation pressure ratio for combustor
        epsilon_n = 0.98;                                                     % Stagnation pressure ratio for nozzle
        eta_c = 0.8;                                                % Compressor efficiency
        eta_b = 0.9;                                                   % Combustion efficiency
        A_e = app.ExitAream2EditField.Value;                                               % Exit area [m^2]

        % Inlet area [m^2]
        A_0 = app.IntakeAream2EditField.Value;

        %%% AIR AND FUEL DATA FROM "HYPERSONIC AIRBREATHING PROPULSION"%%%
        c_p1 = 1900;                                            % Combusted gases specific heat [J/(kg*K)]
        c_p = 1004;                                                 % Air specific heat [J/(kg*K)]
        gamma1 = 1.36;                                          % Combusted gases adiabatic expansion coefficient
        gamma = 1.4;                                               % Air adiabatic expansion coefficient
        H_i = 120900000; 

        w=1;

        for M_0=0:0.5:4
            i=1;
            for z=0:1500:25000                                              % Altitude [m]
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end                                                                                      % Heats of reaction  [J/kg]

                a_0 = sqrt(gamma * R * T_0);                            % Sound speed
                u = a_0 * M_0;                                          % Flight speed

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                % Intake mass flow rate
                mdot_0 = A_0 * u * ro_0;

                %%% PROCESSING %%%

                % Parameters after inlet
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Parameters after compressor
                T0_2 = T0_1 * (1 + 1/eta_c * (OPR^((gamma - 1)/gamma)-1));
                p0_2 = OPR * p0_1;

                % Fuel stechiometric ratio
                f = app.AirfuelratioEditField.Value;

                % Parameters after combustor
                p0_3 = epsilon_b * p0_2;

                % Air-fuel ratio
                alpha = 1/f;

                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Parameters after turbine
                T0_4 = T0_3;
                p0_4 = epsilon_n * p0_3;

                % Outflow rate
                w_e = sqrt(2 * c_p1 * T0_4 * (1 - ((p_0 / (epsilon_n * p0_4))^((gamma1 - 1)/gamma1)))); 

                %%% Thrust
                T = (mdot_0 + mdot_b) * w_e - mdot_0 * u;
                if T<0
                    T=0;
                end

                %%% Specific Thrust
                I_a = (1 + f) * w_e - u;

                %%% Thermal Efficiency
                eta_th = 1 - 1 / (1 + (gamma - 1)/2 * M_0^2);
                %%% Propulsive Efficiency
                eta_p = 2 / (sqrt(T0_3 / (T_0 * (1 + (gamma - 1)/2 * M_0^2))) + 1);

                %%% Thrust Specific Fuel Consumption
                I_sp = (I_a + 2 * u) / (2 * eta_th * H_i);

                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                z_z(w,i) = z;

                i = i+1;
            end
            w = w+1;
        end
    
    
        %if strcmp(app.PlotDropDown.Value,'Thrust')
        cla(app.UIAxes3_2)
        for j=1:1:w-1
            plot(app.UIAxes3_2,z_z(j,:),T_z(j,:));
            hold(app.UIAxes3_2,'on'); 
        end
        title(app.UIAxes3_2,'Ramjet + Compressor (TIT knwon)');
        legend(app.UIAxes3_2,'M=0','M=0.5','M=1','M=1.5','M=2','M=2.5','M=3','M=3.5','M=4');
        xlabel(app.UIAxes3_2,'z [m]');
        ylabel(app.UIAxes3_2,'T [N]');
        %end
    %end
end