function ATR_compare_turbojet_ramjet(app)
clc
    %if strcmp(app.ModelchosenEditField_3.Value,'Turbojet + Ramjet')
        %%% PROJECT DATA %%%
        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]
        %M_proj = 1.2;                                           % Mach On-Design
        % Inlet mass flow rate
        %mdot_proj = 350;

        %%% ENGINE DATA %%%
        OPR = app.TurbojetOPREditField_2.Value;                                                % Overall Pressure Ratio
        %TIT = 1400;                                             % Turbine Inlet Temperature [K]
        %beta_t = 2.61;                                         % Turbine Expansion Ratio
        eta_mc = 1;                                             % Mecanic compressor efficiency
        eta_mt = 0.95;                                          % Mecanic turbine efficiency
        epsilon_d = 0.98;                                       % Pneumatic inlet efficiency
        epsilon_n = 0.98;                                          % Pneumatic nozzle efficiency
        epsilon_b = 0.9;                                          % Pneumatic combustor losses
        eta_n = 0.98;                                              % Nozzle efficiency
        eta_b = 0.9;                                          % Combustor efficiency
        eta_c = 0.880;                                          % Compressor adiabatic efficiency
        eta_t = 0.800;                                          % Turbine adiabatic efficiency
        A_0 = app.IntakeAream2EditField.Value;                                                % Inlet area [m^2]
        A_e = app.ExitAream2EditField.Value;                                               % Exit area [m^2]

        % AFTERBURNER DATA %
        eta_ab= 0.9;                                            % Afterburner efficiency
        epsilon_ab = 1;                                         % Afterburner losses
        T0_e_ab = 1600;                                         % Afterburner exit temperature [K]
        mdot_ab = 0.417;                                        % Afterburner propellant mass flow [kg/s]
        A_e_ab = 0.12272;                                       % Afterburner exit area

        %%% AIR AND FUEL DATA %%%
        R1 = 293.77;                                            % Combusted gases constant [J/(kg*K)]
        c_p = 1004;                                             % Air specific heat [J/(kg*K)]
        c_p1 = 1900;                                            % Combusted gases specific heat [J/(kg*K)]
        gamma = 1.4;                                          % Air adiabatic expansion coefficient
        gamma1 = 1.36;                                           % Combusted gases adiabatic expansion coefficient
        H_i = 120900000;                                         % Heats of reaction [J/kg]

        w=1;

        for M_0=0.5:0.5:2.5
            i=1;

            for z=0:1500:25000
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end

                a = sqrt(gamma * R * T_0);                              % Sound speed
                u = a * M_0;                                            % Flight speed 

                % Intake mass flow rate
                mdot_0 = A_0 * u * ro_0;        

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));
                %p0_0_proj = p_0 * (1+(gamma - 1)/2 * M_proj^(2))^(gamma/(gamma - 1));

                %%% PROCESSING %%%

                % Values after inlet
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Values after compression
                T0_2 = T0_1 * (1 + 1/eta_c * (OPR^((gamma - 1)/gamma)-1));
                p0_2 = OPR * p0_1;

                % Values after combustion
                f = app.AirfuelratioEditField.Value;
                TIT = T0_2 + eta_b*f*(H_i/c_p1);

                p0_3 = epsilon_b * p0_2;
                T0_3 = TIT;

                %Variation of M_0 makes change air flow mass
                %mdot_0 = mdot_proj * (p0_3/(p0_0_proj * OPR * epsilon_d * epsilon_d));    

                % Fuel ratio
                %f = c_p1 * (T0_3 - T0_2)/((eta_b * H_i) - c_p1 * (T0_3 - T0_2)); 
                % Air ratio
                alpha = 1/f; 
                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Expansion Turbine Ratio
                beta_t = (1 - c_p * (T0_2 - T0_1) / (c_p1 * eta_mc * eta_mt * eta_t * (1 + f) * T0_3))^(-gamma1/(gamma1 - 1));

                % Values after expansion in turbine
                T0_4 = T0_3 - c_p/c_p1 * (1 / (eta_mt * eta_mc)) * ((T0_2 - T0_1)/(1 + f)); 
                p0_4 = p0_3 / beta_t;

                % Exit values
                T0_e = T0_4;
                p0_e = epsilon_n * p0_4;

                % Values with afterburner
                p0_e_ab = epsilon_ab * p0_4;

                % Critic pressure 
                p_cr = p0_e / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));
                % Critic pressure with afterburner 
                p_cr_ab = p0_e_ab / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));

                % Is nozzle adpated?
                if p_0 < p_cr
                    p_e = p_cr;
                    M_e = 1;
                else % Adapted nozzle
                    p_e = p_0;
                    M_e = sqrt(2/(gamma1 - 1) * ((p0_e/p_e)^((gamma1 - 1)/gamma1)-1));
                end
                % With afterburner
                if p_0 < p_cr_ab
                    p_e_ab = p_cr_ab;
                    M_e_ab = 1;
                else % Adapted nozzle
                    p_e_ab = p_0;
                    M_e_ab = sqrt(2/(gamma1 - 1) * ((p0_e_ab/p_e_ab)^((gamma1 - 1)/gamma1)-1));
                end


                % Static values
                T_e = T0_e / (1 + (gamma1 - 1)/2 * M_e^2);
                ro_e = p_e / (R1 * T_e);
                % Static values with afterburner
                T_e_ab = T0_e_ab / (1 + (gamma1 - 1)/2 * M_e_ab^2);
                ro_e_ab = p_e_ab / (R1 * T_e_ab);

                % Outflow rate
                w_e = M_e * sqrt(gamma1 * R1 * T_e);
                % with afterburner
                w_e_ab = M_e_ab * sqrt(gamma1 * R1 * T_e_ab);

                % Exit area
                %A_e = (mdot_0 + mdot_b)/(ro_e * w_e);
                % with afterburner
                %A_e_ab = (mdot_0 + mdot_b + mdot_ab)/(ro_e_ab * w_e_ab);

                % Outflow rate
                %w_e = sqrt(2 * eta_n * c_p1 * T0_e * (1 - ((p_e / (p0_e))^((gamma1 - 1)/gamma1)))); 
                % Outflow rate wuth afterburner
                %w_e_ab = sqrt(2 * eta_n * c_p1 * T0_e_ab * (1 - ((p_e / (p0_e_ab))^((gamma1 - 1)/gamma1))));

                %%% Thrust
                T = mdot_0 * ((1 + f) * w_e - u) + A_e * (p_e - p_0);
                if T<0
                    T=0;
                end

                %%% Thrust with afterburner
                T_ab = mdot_0 * ((1 + f) * w_e_ab - u) + A_e_ab * (p_e - p_0);
                if T_ab<0
                    T_ab=0;
                end

                %%% Specific Thrust
                I_a = ((alpha + 1) / alpha) * w_e - u;

                %%% Thrust Specific Fuel Consumption
                I_sp = mdot_b / T;
                %%% Thrust Specific Fuel Consumption with afterburner
                I_sp_ab = (mdot_b + mdot_ab) / T_ab;

                %%% Thermal Efficiency
                eta_th = ((1 + f) * w_e^(2)/2 - u^(2)/2)/(f * H_i);
                %%% Propulsive Efficiency
                eta_p = 2 * ((1 + f) * (w_e/u) - 1)/((1 + f)*(w_e/u)^(2) - 1);
                %%% Overall Efficiency
                eta_0 = eta_p * eta_th;

                T_z(w,i) = T;
                I_a_z (w,i) = I_a;
                I_sp_z (w,i) = I_sp;
                T_ab_z(w,i) = T_ab;
                I_sp_ab_z (w,i) = I_sp_ab;
                eta_th_z (w,i) = eta_th;
                eta_p_z (w,i) = eta_p;
                eta_0_z (w,i) = eta_0;
                z_z(w,i) = z;

                i = i+1;
            end
            w = w+1;
        end

        %%% ENGINE DATA %%%
        %T0_3 = 2200;                                                 % Temperature after combustion [K]
        OPR = app.RamjetOPREditField.Value;                                                    % Overall Pressure Ratio
        %mdot_0 = 284;                                               % Inlet mass flow rate [kg/s]
        epsilon_d = 0.98;                                                     % Stagnation pressure ratio for inlet
        epsilon_b = 0.985;                                                     % Stagnation pressure ratio for combustor
        epsilon_n = 1;                                                     % Stagnation pressure ratio for nozzle
        eta_c = 0.9;                                                % Compressor efficiency
        eta_b = 0.95;                                                   % Combustion efficiency
        A_e = app.ExitAream2EditField.Value;                                               % Exit area [m^2]

        % Inlet area [m^2]
        A_0 = app.IntakeAream2EditField.Value;

        % %%% AIR AND FUEL DATA FROM "HYPERSONIC AIRBREATHING PROPULSION"%%%
        % c_p1 = 1660;                                            % Combusted gases specific heat [J/(kg*K)]
        % c_p = 1004;                                                 % Air specific heat [J/(kg*K)]
        % gamma1 = 1.36;                                          % Combusted gases adiabatic expansion coefficient
        % gamma = 1.4;                                               % Air adiabatic expansion coefficient
        % H_i = 120900000;                                         % Heats of reaction [J/kg]

        for M_0=3:0.5:4
            i=1;
            for z=0:1500:25000                                              % Altitude [m]
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end                                                                                      % Heats of reaction  [J/kg]

                a_0 = sqrt(gamma * R * T_0);                            % Sound speed
                u = a_0 * M_0;                                          % Flight speed

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                mdot_0 = A_0 * u * ro_0;

                %%% PROCESSING %%%

                % Parameters after inlet
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Parameters after compressor
                T0_2 = T0_1 * (1 + 1/eta_c * (OPR^((gamma - 1)/gamma)-1));
                p0_2 = OPR * p0_1;

                % Fuel stechiometric ratio
                f = app.AirfuelratioEditField.Value;

                % Parameters after combustor
                T0_3 = T0_2 + eta_b*f*(H_i/c_p1);
                p0_3 = epsilon_b * p0_2;

                % Fuel ratio
                %f = (c_p1 * (T0_3 - T0_2)) / (eta_b * H_i - c_p1 * (T0_3 - T0_2));
                % Air-fuel ratio
                alpha = 1/f;

                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Parameters after turbine
                T0_4 = T0_3;
                p0_4 = epsilon_n * p0_3;

                % Outflow rate
                w_e = sqrt(2 * c_p1 * T0_4 * (1 - ((p_0 / (epsilon_n * p0_4))^((gamma1 - 1)/gamma1)))); 

                %%% Thrust
                T = (mdot_0 + mdot_b) * w_e - mdot_0 * u;
                if T<0
                    T=0;
                end

                %%% Specific Thrust
                I_a = (1 + f) * w_e - u;

                %%% Thrust
                %T = I_a * mdot_0;

                %%% Thermal Efficiency
                eta_th = 1 - 1 / (1 + (gamma - 1)/2 * M_0^2);
                %%% Propulsive Efficiency
                eta_p = 2 / (sqrt(T0_3 / (T_0 * (1 + (gamma - 1)/2 * M_0^2))) + 1);

                %%% Thrust Specific Fuel Consumption
                I_sp = (I_a + 2 * u) / (2 * eta_th * H_i);

                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                z_z(w,i) = z;

                i = i+1;
            end
            w = w+1;
        end
        %if strcmp(app.PlotDropDown.Value,'Thrust')
        cla(app.UIAxes3_3)
        for j=1:1:w-1
            plot(app.UIAxes3_3,z_z(j,:),T_z(j,:));
            hold(app.UIAxes3_3,'on'); 
        end
        title(app.UIAxes3_3,'Turbojet + Ramjet');
        legend(app.UIAxes3_3,'M=0.5','M=1','M=1.5','M=2','M=2.5','M=3','M=3.5','M=4');
        xlabel(app.UIAxes3_3,'z [m]');
        ylabel(app.UIAxes3_3,'T [N]');
        %end        
    %end
end