function DMR_compare_simple_ramjet(app)
    clc
    %if strcmp(app.ModelchosenEditField_4.Value,'Simple Ramjet')
        %%% PROJECT DATA %%%
        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]

        %%% ENGINE DATA %%%
        %T0_3 = 1900;                                                 % Temperature after combustion [K]
        %mdot_0 = 284;                                               % Inlet mass flow rate [kg/s]
        %epsilon_d = 0.35;                                                    % Stagnation pressure ratio for inlet
        epsilon_b = 0.95;                                                     % Stagnation pressure ratio for combustor
        epsilon_n = 0.9;                                                     % Stagnation pressure ratio for nozzle
        eta_b = 0.95;                                                   % Combustion efficiency
        %beta_d = 0.8;                                                   % Compreesion ratio of dinamic intake
        T_Z22 = 2970;                                                    % Adiabatic flame temperature using the Z22 mechanism
        T_JAC = 2750;                                                     % Adiabatic flame temperature using the Jachimowski mechanism

        % Inlet area [m^2]
        A_0 = app.IntakeAream2EditField_2.Value;
        % Nozzle exit area [m^2]
        A_e_2D = 15.9;
        A_e_3D = 111.2;

        %%% AIR AND FUEL DATA FROM "HYPERSONIC AIRBREATHING PROPULSION"%%%
        c_p1 = 1900;                                            % Combusted gases specific heat [J/(kg*K)]
        c_p = 1004;                                                 % Air specific heat [J/(kg*K)]
        gamma1 = 1.33;                                          % Combusted gases adiabatic expansion coefficient
        gamma = 1.4;                                               % Air adiabatic expansion coefficient
        H_i = 120900000;                                          % Heats of reaction [J/kg]
        f_st = 0.028;                                             % Stechiometric fuel-air ratio for hydrogen

        w=1;
        T_old = 0;

        for M_0=4:0.5:8
            i=1;
            for z=18000:2000:40000                                               % Altitude [m]
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end                                                                                      % Heats of reaction  [J/kg]

                a_0 = sqrt(gamma * R * T_0);                            % Sound speed
                u = a_0 * M_0;                                          % Flight speed

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                %%% PROCESSING %%%

                %epsilon_spil = 1;
                if M_0 < 4.5
                    epsilon_spil = 0.72;
                elseif M_0 < 5
                    epsilon_spil = 0.76;
                elseif M_0 < 5.5
                    epsilon_spil = 0.8;
                elseif M_0 < 6
                    epsilon_spil = 0.84;
                elseif M_0 < 6.5
                    epsilon_spil = 0.87;
                elseif M_0 < 7
                    epsilon_spil = 0.9;
                elseif M_0 < 7.5
                    epsilon_spil = 0.92;
                elseif M_0 < 8
                    epsilon_spil = 0.94;
                elseif M_0 == 8
                    epsilon_spil = 0.96;
                end
                %epsilon_spil = 1;

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                mdot_0 = epsilon_spil * A_0 * u * ro_0;

                if M_0 < 5
                    epsilon_d = app.AdiabaticInletEfficiencylowspeedEditField.Value;
                elseif M_0 >= 5 && M_0 <= 7.5
                    epsilon_d = app.AdiabaticInletEfficiencylowspeedEditField.Value;
                else 
                    epsilon_d = app.AdiabaticInletEfficiencyhighspeedEditField.Value;
                end

                % Parameters before intake
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Parameters after dinamic intake
                T0_2 = T0_1;
                p0_2 = p0_1;

                % Parameters after combustor
        %         if M_0 < 5
        %             T0_3 = 2698.49;
        %         elseif M_0 <= 7
        %             T0_3 = 2563.33;
        %         elseif M_0 <= 8
        %             T0_3 = 2467.94;
        %         end
                %T0_3 = T0_2 + eta_b*f_st*(H_i/c_p1);
                %if T0_3 > 2750
                if M_0 >= 5 && M_0 <= 7
                    T0_3 = T_JAC;
                else
                    T0_3 = T_Z22;
                end
                %end

                % Parameters after combustor
                p0_3 = epsilon_b * p0_2;

                % Fuel ratio
                f = (c_p1 * (T0_3 - T0_2)) / (eta_b * H_i - c_p1 * (T0_3 - T0_2));
                if f < 0.025
                    f = f_st;
                end
                %f = f_st;
                % Air-fuel ratio
                alpha = 1/f;

                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Parameters after nozzle
                T0_4 = T0_3;
                p0_4 = epsilon_n * p0_3;

                % Outflow rate
                w_e = sqrt(2 * c_p1 * T0_4 * (1 - ((p_0 / (epsilon_n * p0_3))^((gamma1 - 1)/gamma1)))); 

                %%% Thrust
                T = (mdot_0 + mdot_b) * w_e - mdot_0 * u;
                if T<0
                    T=0;
                end

                %%% Specific Thrust
                I_a = (1 + f) * w_e - u;

                %%% Thrust
                %T = I_a * mdot_0;

                %%% Thermal Efficiency
                eta_th = 1 - 1 / (1 + (gamma - 1)/2 * M_0^2);
                %%% Propulsive Efficiency
                eta_p = 2 / (sqrt(T0_3 / (T_0 * (1 + (gamma - 1)/2 * M_0^2))) + 1);

                %%% Thrust Specific Fuel Consumption
                I_sp = (I_a + 2 * u) / (2 * eta_th * H_i);

                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                z_z(w,i) = z;

                i = i+1;
            end
            %T_old = T_z(w,1);
            w = w+1;
        end
        %if strcmp(app.PlotDropDown_2.Value,'Thrust')
        cla(app.UIAxes3_5)
        for j=1:1:w-1
            plot(app.UIAxes3_5,z_z(j,:),T_z(j,:));
            hold(app.UIAxes3_5,'on'); 
        end
        title(app.UIAxes3_5,'Simple Ramjet');
        legend(app.UIAxes3_5,'M=4','M=4.5','M=5','M=5.5','M=6','M=6.5','M=7','M=7.5','M=8');
        xlabel(app.UIAxes3_5,'z [m]');
        ylabel(app.UIAxes3_5,'T [N]');
        %end        
    %end
end
