function classic_turbofan(app)
    clc
    if strcmp(app.ModelchosenEditField_6.Value,'Turbofan')

        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]
        
         %%% ENGINE DATA %%%

        OPR = app.OverallPressureRatioEditField_2.Value;                                                 % Overall Pressure Ratio
        TIT = app.TurbineInletTemperatureKEditField_4.Value;                                                 % Turbine Inlet Temperature
        BPR = app.ByPassRatioEditField.Value;                                                 % Bypass Ratio
        FPR = app.FanPressureRatioEditField.Value;                                                 % Fan Pressure Ratio
        eta_mc = 1;                                              % Mecanic compressor efficiency
        eta_mt = 1;                                              % Mecanic turbine efficiency
        epsilon_d = app.PneumaticinletefficiencyEditField_3.Value;                                           % Pneumatic inlet efficiency
        epsilon_b = app.PneumaticcombustorefficiencyEditField_3.Value;                                           % Pneumatic hot-flow nozzle efficiency
        epsilon_n = app.PneumaticnozzleefficiencyEditField_3.Value;                                           % Pneumatic combustor losses
        %beta_n = ;                                              % Expasion nozzle ratio
        eta_b = app.AdiabaticcombustorefficiencyEditField_4.Value;                                               % Combustor efficiency
        eta_af = app.AdiabaticfanefficiencyEditField.Value;                                              % Adiabatic fan efficiency
        eta_c = app.AdiabaticcompressorefficiencyEditField_3.Value;
        eta_an = 1;                                              % Adiabatic nozzle efficiency
        eta_tH = app.AdiabatichighturbineefficiencyEditField_2.Value;                                              % High-Pressure Turbine efficiency
        eta_tL = app.AdiabaticlowturbineefficiencyEditField_2.Value;                                              % Low-Pressure Turbine efficiency
        A_0 = app.Inletaream2EditField_4.Value;                                                % Inlet area [m^2]
        A_e = app.Nozzleexitaream2EditField_3.Value;                                                 % Exit area [m^2]
        %mdot_0 = 684;                                               % Inlet mass flow rate [kg/s]
        
        %%% AIR AND FUEL DATA %%%

        R1 = 293.77;                                            % Combusted gases constant [J/(kg*K)]
        c_p = 1004;                                             % Air specific heat [J/(kg*K)]
        c_p1 = app.CombustedgasspecificheatJkgKEditField_3.Value;                                            % Combusted gases specific heat [J/(kg*K)]
        gamma = 1.375;                                          % Air adiabatic expansion coefficient
        gamma1 = 1.3;                                           % Combusted gases adiabatic expansion coefficient
        H_i = app.HeatsofreactionJkgEditField_3.Value;                                         % Heats of reaction [J/kg]

        w=1;
        
        for M_0=0.4:0.2:2
            i=1;
            for z=5000:1000:20000

                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end

                 a = sqrt(gamma * R * T_0);                              % Sound speed
                u = a * M_0;                                            % Flight speed 

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));
                %p0_0_proj = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                % Considering m_dot0 = mdot_f + mdot_c

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                mdot_0 = A_0 * u * ro_0;
                
                %%% PROCESSING %%%

                % Values after inlet
                T0_1 = T0_0; 
                p0_1 = p0_0 * epsilon_d;

                f_st = 0.014;
 
                % Cold-flow temperature after fan compression 
                T0_2f = T0_1 * (1 + 1/eta_af * (FPR^((gamma - 1)/gamma)-1)); 
                p0_2f = p0_1 * FPR;

                % Hot-flow parameters after fan compression 
                T0_2c = T0_2f; 
                p0_2c = p0_1 * FPR;

                % Values after compression (both fan and compressor)
                T0_2 = T0_1 * (1 + 1/eta_c * (OPR^((gamma - 1)/gamma)-1));
                p0_2 = p0_1 * OPR;

                % Values after combustion
                T0_3 = TIT;
                p0_3 = p0_2 * epsilon_b;

                %Variation of M_0 makes change air flow mass
                %mdot_0 = mdot_proj * (p0_3/(p0_0_proj * OPR * epsilon_d * epsilon_d));

                % Hot mass flow rate
                mdot_c = mdot_0 / (1 + BPR); 
                % Cold mass flow rate
                mdot_f = mdot_0 - mdot_c; 

                % Air ratio
                alpha = (eta_b * H_i)/(c_p1 * (TIT - T0_2)) - 1;
                % Fuel ratio
                f = 1/alpha;
                % Propellant mass flow rate
                mdot_b = mdot_c * f;

                % Expansion High-Pressure Turbine Ratio
                beta_tH = (1 - c_p * (T0_2 - T0_2c) / (c_p1 * eta_mc * eta_mt * eta_tH * (1 + f) * T0_3))^(-gamma1/(gamma1 - 1));

                % Parameters after expansion in high pressure turbine
                T0_4 = TIT - c_p/c_p1 * (1/eta_mc * eta_mt) * (T0_2 - T0_2c)/(1 + f); 
                p0_4 = p0_3 / beta_tH;

                % Expansion Low-Pressure Turbine Ratio
                beta_tL = (1 - (1 + BPR) * c_p * (T0_2c - T0_1) / (c_p1 * eta_mc * eta_mt * eta_tL * (1 + f) * T0_4))^(-gamma1/(gamma1 - 1));

                % Parameters after expansion in low pressure turbine
                T0_5 = T0_4 - c_p/c_p1 * (1/eta_mc * eta_mt) * (T0_2c - T0_1) * (1 + BPR)/(1 +f); 
                p0_5 = p0_4 / beta_tL;

                % Exit values from 'hot' nozzle
                T0_e = T0_5;
                p0_e = epsilon_n * p0_5;

                % Critic pressure for 'hot' nozzle
                p_cr = p0_e / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));

                if p_0 < p_cr
                    p_e = p_cr;
                    M_e = 1;
                else % Adapted nozzle
                    p_e = p_0;
                    M_e = sqrt(2/(gamma1 - 1) * ((p0_e/p_e)^((gamma1 - 1)/gamma1)-1));
                end

                % Static values
                T_e = T0_e / (1 + (gamma1 - 1)/2 * M_e^2);
                ro_e = p_e / (R1 * T_e);

                w_c = M_e * sqrt(gamma1 * R1 * T_e);

            %     % 'Cold' nozzle is considered adapted
            %     M_e_f = 1;
            %     p_e_f = p0_2f / ((gamma + 1)/2)^(gamma / (gamma - 1));
            % 
            %     % Static values
            %     T_e_f = T0_2f / ((gamma + 1)/2);
            %     ro_e_f = p_e_f / (R * T_e_f);
            % 
            %     w_f = M_e_f * sqrt(gamma * R * T_e_f);

                % Exit area
                %A_e = (mdot_0 + mdot_b)/(ro_e * w_e);

                %w_c = sqrt(2 * c_p1 * T0_e * eta_an * (1 - (p_e/p0_e)^((gamma1 - 1)/gamma1))); % Exit hot flow speed

                w_f = sqrt(2 * c_p * T0_2f * eta_an * (1 - (p_0/p0_2f)^((gamma - 1)/gamma))); % Exit cold flow speed

                w_eq = w_f * BPR + w_c; % Exit equivalent speed

                %%% Thrust
                T_max = mdot_c * ((1 + f) * w_c + BPR * w_f - (1 + BPR) * u) + A_e * (p_e - p_0);

                %T_max = (mdot_c + mdot_b)* w_c + mdot_f * w_f - (mdot_c +mdot_f) * u + A_e * (p_e-p_0);
            %     if z < 3048
            %         K_MZ = 1 - 1.037 * M_0 + 0.582 * M_0^2;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 3048 && z < 6096
            %         K_MZ = 0.81 - 0.768 * M_0 + 0.474 * M_0^2;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 6096 && z < 7620
            %         K_MZ = 0.57 - 0.261 * M_0 + 0.084 * M_0^2;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 7620 && z < 9144
            %         K_MZ = 0.39;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 9144 && z < 10668
            %         K_MZ = 0.33;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 10668 && z < 12192
            %         K_MZ = 0.27;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 12192 && z < 13716
            %         K_MZ = 0.21;
            %         T = T_max * K_MZ * 0.8;
            %     elseif z >= 13716
            %         K_MZ = 0.16;
            %         T = T_max * K_MZ * 0.8;
            %     end
                T = T_max;    

                %%% Specific Thrust
                I_a = ((1 + f) * w_c + BPR * w_f - (1 + BPR) * u)/(1 + BPR);

                %%% Specific Thrust of hot mass flow
                I_ac = (1 + f) * w_c + BPR * w_f - (1 + BPR) * u;

                %%% Thrust Specific Fuel Consumption
                %I_sp = f / ((1 + f) * w_c + BPR * w_f - (1 + BPR) * u);
                I_sp = mdot_b / T;

                %%% Thermal Efficiency
                eta_th = ((1 + f) * w_eq^(2)/2 - u^(2)/2)/(f * H_i);
                %%% Propulsive Efficiency
                eta_p = 2 * ((1 + f) * (w_eq/u) - 1)/((1 + f)*(w_eq/u)^(2) - 1);
                %%% Overall Efficiency
                eta_0 = eta_p * eta_th;

                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                eta_th_z(w,i) = eta_th;
                eta_p_z(w,i) = eta_p;
                eta_0_z(w,i) = eta_0;
                z_z(w,i) = z;
                                
                i=i+1;
            end
            w=w+1;
        end
        
        if strcmp(app.PlotDropDown_3.Value,'Thrust')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),T_z(j,:));
                hold(app.UIAxes2_2,'on'); 
            end
            title(app.UIAxes2_2,'Thrust');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'T [N]');
        elseif strcmp(app.PlotDropDown_3.Value,'SpecificThrust')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),I_a_z(j,:));
                hold(app.UIAxes2_2,'on');
            end
            title(app.UIAxes2_2,'Specific Thrust');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'I_a [N*s/kg]');                    
        elseif strcmp(app.PlotDropDown_3.Value,'TSFC')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),I_sp_z(j,:));
                hold(app.UIAxes2_2,'on');
            end
            title(app.UIAxes2_2,'TSFC');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'TSFC[kg/s/N]');                    
        end  
    end    
end