function classic_twin_turbojet(app)
    clc
    if strcmp(app.ModelchosenEditField_6.Value,'Twin-Spool Classic Turbojet')

        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]
        
        %%% ENGINE DATA %%%

        beta_cL = app.LowCompressorRatioEditField.Value;                                        % Low Compressor Ratio
        beta_cH = app.HighCompressorRatioEditField.Value;                                             % High Compressor Ratio
        TIT = app.TurbineInletTemperatureKEditField_3.Value;                                             % Turbine Inlet Temperature [K]
        %beta_t = 2.61;                                         % Turbine Expansion Ratio
        eta_mcL = 1;                                            % Mecanic low compressor efficiency
        eta_mcH = 1;                                            % Mecanic high compressor efficiency
        eta_mtL = 0.95;                                         % Mecanic low turbine efficiency
        eta_mtH = 0.95;                                         % Mecanic  high turbine efficiency
        epsilon_d = app.PneumaticinletefficiencyEditField_2.Value;                                       % Pneumatic inlet efficiency
        epsilon_n = app.PneumaticnozzleefficiencyEditField_2.Value;                                          % Pneumatic nozzle efficiency
        epsilon_b = app.PneumaticcombustorefficiencyEditField_2.Value;                                          % Pneumatic combustor losses
        eta_n = 1;                                              % Nozzle efficiency
        eta_b = app.AdiabaticcombustorefficiencyEditField_3.Value;                                          % Combustor efficiency
        eta_cL = app.AdiabaticlowcompressorefficiencyEditField.Value;                                         % Low compressor efficiency
        eta_cH = app.AdiabatichighcompressorefficiencyEditField.Value;                                         % High compressor efficiency
        eta_tL = app.AdiabaticlowturbineefficiencyEditField.Value;                                         % Low turbine efficiency
        eta_tH = app.AdiabatichighturbineefficiencyEditField.Value;                                         % High turbine efficiency
        A_0 = app.Inletaream2EditField_3.Value;                                            % Inlet area [m^2]
        A_e = app.Nozzleexitaream2EditField_2.Value;                                            % Exit area [m^2]

        %%% AIR AND FUEL DATA %%%
        R1 = 293;                                            % Combusted gases constant [J/(kg*K)]
        c_p = 1004;                                             % Air specific heat [J/(kg*K)]
        c_p1 = app.CombustedgasspecificheatJkgKEditField_2.Value;                                            % Combusted gases specific heat [J/(kg*K)]
        gamma = 1.375;                                          % Air adiabatic expansion coefficient
        gamma1 = 1.3;                                           % Combusted gases adiabatic expansion coefficient
        H_i = app.HeatsofreactionJkgEditField_2.Value;                                         % Heats of reaction [J/kg]

        w=1;
        
        for M_0=0.4:0.2:2
            i=1;
            for z=5000:1000:20000

                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end

                a = sqrt(gamma * R * T_0);                              % Sound speed
                u = a * M_0;                                            % Flight speed 

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                %mdot_0 = 186;                                           % [kg/s]
                mdot_0 = A_0 * u * ro_0;

                %%% PROCESSING %%%

                % Values after inlet
                T0_1 = T0_0;
                p0_1 = epsilon_d * p0_0;

                % Values after first compression
                T0_21 = T0_1 * (1 + 1/eta_cL * (beta_cL^((gamma - 1)/gamma) - 1));
                p0_21 = beta_cL * p0_1;

                % Values after second compression
                T0_2 = T0_21 * (1 + 1/eta_cH * (beta_cH^((gamma - 1)/gamma) - 1));
                p0_2 = beta_cH * p0_21;

                % Values after combustion
                p0_3 = epsilon_b * p0_2;
                T0_3 = TIT;

                % Fuel ratio
                f = c_p1 * (T0_3 - T0_2)/((eta_b * H_i) - c_p1 * (T0_3 - T0_2)); 
                % Air ratio
                alpha = 1/f; 
                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Expansion High-Pressure Turbine Ratio
                beta_tH = (1 - c_p * (T0_2 - T0_21) / (c_p1 * eta_mcH * eta_mtH * eta_tH * (1 + f) * T0_3))^(-gamma1/(gamma1 - 1));

                % Values after first expansion in turbine
                T0_41 = T0_3 - c_p/c_p1 * (1 / (eta_mtH * eta_mcH)) * ((T0_2 - T0_21)/(1 + f)); 
                p0_41 = p0_3 / beta_tH;

                % Expansion Low-Pressure Turbine Ratio
                beta_tL = (1 - c_p * (T0_21 - T0_1) / (c_p1 * eta_mcL * eta_mtL * eta_tL * (1 + f) * T0_41))^(-gamma1/(gamma1 - 1));

                % Values after second expansion in turbine
                T0_4 = T0_41 - c_p/c_p1 * (1 / (eta_mtL * eta_mcL)) * ((T0_21 - T0_1)/(1 + f)); 
                p0_4 = p0_41 / beta_tL;

                % Exit values
                T0_e = T0_4;
                p0_e = epsilon_n * p0_4;

                % Critic pressure 
                p_cr = p0_e / ((gamma1 + 1)/2)^(gamma1 / (gamma1 - 1));

                % Is nozzle adpated?
                if p_0 < p_cr
                    p_e = p_cr;
                    M_e = 1;
                else % Adapted nozzle
                    p_e = p_0;
                    M_e = sqrt(2/(gamma1 - 1) * ((p0_e/p_e)^((gamma1 - 1)/gamma1)-1));
                end

                % Static values
                T_e = T0_e / (1 + (gamma1 - 1)/2 * M_e^2);
                ro_e = p_e / (R1 * T_e);

                % Exit area
                %A_e = (mdot_0 + mdot_b)/(ro_e * w_e);  

                % Outflow rate
                %w_e = sqrt(2 * eta_n * c_p1 * T0_e * (1 - ((p_e / (p0_e))^((gamma1 - 1)/gamma1)))); 
                w_e = M_e * sqrt(gamma1 * R1 * T_e);

                %%% Thrust
                T = mdot_0 * ((1 + f) * w_e - u) + A_e * (p_e - p_0);
                if T<0
                    T=0;
                end

                %%% Specific Thrust
                I_a = T / mdot_0;

                %%% Thrust Specific Fuel Consumption
                I_sp = mdot_b / T;

                %%% Thermal Efficiency
                eta_th = ((1 + f) * w_e^(2)/2 - u^(2)/2)/(f * H_i);
                %%% Propulsive Efficiency
                eta_p = 2 * ((1 + f) * (w_e/u) - 1)/((1 + f)*(w_e/u)^(2) - 1);
                %%% Overall Efficiency
                eta_0 = eta_p * eta_th;

                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                %T_ab_z(w,i) = T_ab;
                %I_sp_ab_z(w,i) = I_sp_ab;
                eta_th_z(w,i) = eta_th;
                eta_p_z(w,i) = eta_p;
                eta_0_z(w,i) = eta_0;
                z_z(w,i) = z;
                
                i=i+1;
            end
            w=w+1;
        end
        
        if strcmp(app.PlotDropDown_3.Value,'Thrust')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),T_z(j,:));
                hold(app.UIAxes2_2,'on'); 
            end
            title(app.UIAxes2_2,'Thrust');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'T [N]');
        elseif strcmp(app.PlotDropDown_3.Value,'SpecificThrust')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),I_a_z(j,:));
                hold(app.UIAxes2_2,'on');
            end
            title(app.UIAxes2_2,'Specific Thrust');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'I_a [N*s/kg]');                    
        elseif strcmp(app.PlotDropDown_3.Value,'TSFC')
            cla(app.UIAxes2_2)
            for j=1:1:w-1
                plot(app.UIAxes2_2,z_z(j,:),I_sp_z(j,:));
                hold(app.UIAxes2_2,'on');
            end
            title(app.UIAxes2_2,'TSFC');
            legend(app.UIAxes2_2,'M=0.4','M=0.6','M=0.8','M=1','M=1.2','M=1.4','M=1.6','M=1.8','M=2');
            xlabel(app.UIAxes2_2,'z [m]');
            ylabel(app.UIAxes2_2,'TSFC[kg/s/N]');                    
        end  
    end    
end