function completed_ramjet(app)
    clc
    if strcmp(app.ModelchosenEditField_4.Value,'Completed Ramjet')
        %%% PROJECT DATA %%%
        g = 9.81;                                               % [kg/s^2]
        R = 287;                                                % Universal gas constant [N*m/(kg*K)]
        p_amb = 101325;                                         % [Pa]
        T_amb = 288.15;                                         % [K]
        ro_amb = 1.225;                                         % [kg/m^3]

        %%% DMR dimensions %%%
        L_in = 30.4059;                                                % Intake length [m]
        cr = 7.75;                                                     % Inlet contraction ratio
        L_com = 8.35;                                                  % Combustor length [m]
        L_2Dnoz = 12.98;                                               % 2D nozzle length [m]
        er_2D = 2.19;                                                  % 2D nozzle expansion ratio
        L_3Dnoz = 42.255;                                              % 3D nozzle length [m]    
        er_3D = 10.1;                                                  % 3D nozzle expansion ratio 

        %%% ENGINE DATA %%%
        T_Z22 = 2750;                                                   % Maximum temperature after combustion [K]
        %mdot_0 = 284;                                                  % Inlet mass flow rate [kg/s]
        %epsilon_d = 0.35;                                                % Stagnation pressure ratio for inlet
        epsilon_b = 1;                                               % Stagnation pressure ratio for combustor
        epsilon_n = 0.95;                                               % Stagnation pressure ratio for nozzle
        eta_b = 0.9;                                                   % Combustion efficiency                                                    % Refrigerant constant
        %epsilon_spil = 0.5;                                             % Mass-flow rate losses due to spillage

        % Inlet area [m^2]
        A_0 = app.IntakeAream2EditField_2.Value;
        % Nozzle throat area [m^2]
        A_t = app.ThroatAream2EditField.Value;
        % Nozzle exit area [m^2]
        A_e1 = app.FirstNozzleExitAream2EditField.Value;
        A_e2 = app.SecondNozzleExitAream2EditField.Value;

        %%% AIR AND FUEL DATA FROM "HYPERSONIC AIRBREATHING PROPULSION" %%%
        c_p1 = 1900;                                            % Combusted gases specific heat [J/(kg*K)]
        c_p = 1004;                                                 % Air specific heat [J/(kg*K)]
        gamma1 = 1.33;                                          % Combusted gases adiabatic expansion coefficient
        gamma = 1.4;                                               % Air adiabatic expansion coefficient
        H_i = 120900000;                                          % Heats of reaction [J/kg]
        f_st = 0.028;                                             % Stechiometric fuel-air ratio for hydrogen

        w=1;
        %T_old = 0;

        for M_0=4:0.5:8
            i=1;
            for z=18000:2000:40000                                               % Altitude [m]
                %%% ATMOSPHERE MODEL %%%

                % Subscripts 's' is for stratosphere
                z_s = 11000;                                            % [m]
                p_s = p_amb * (1 - 0.0065 * z_s / T_amb)^(5.2561);      % [Pa]
                T_s = 216.65;                                           % [K]
                ro_s = ro_amb * (1 - 0.0065 * z_s / T_amb)^(4.2561);    % [kg/m^3]

                % Subscripts '20' is for 20 km of altitude
                z_20 = 20000;                                           % [m]
                p_20 = p_s * exp((-g * (z_20 - z_s)) / (R * T_s));           % [Pa]
                T_20 = 216.65;                                          % [K]
                ro_20 = ro_s * exp((-g * (z_20 - z_s)) / (R * T_s));         % [kg/m^3]

                if z <= 11000
                    T_0 = T_amb - 0.0065 * z;                           % Static temperature [K]
                    p_0 = p_amb * (1 - 0.0065 * z / T_amb)^(5.2561);    % Static pressure [Pa]
                    ro_0 = ro_amb * (1 - 0.0065 * z / T_amb)^(4.2561);  % Density [kg/m^3]
                elseif z > 11000 && z <= 20000
                    T_0 = T_s; 
                    p_0 = p_s * exp((-g * (z - z_s)) / (R * T_s));
                    ro_0 = ro_s * exp((-g * (z - z_s)) / (R * T_s));
                else
                    T_0 = T_20 + 0.001 * (z - z_20); 
                    p_0 = p_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001));
                    ro_0 = ro_20 * (1 + 0.001 * (z - z_20) / T_20)^(-g / (R * 0.001) - 1);
                end                                                                                      % Heats of reaction  [J/kg]

                a_0 = sqrt(gamma * R * T_0);                            % Sound speed
                u = a_0 * M_0;                                          % Flight speed

                % Inlet values
                T0_0 = T_0 * (1+(gamma - 1)/2 * M_0^(2)); 
                p0_0 = p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1));
                %epsilon_d = 1/((1 + (gamma-1)/2*M_0^2)^((gamma-1)/gamma));

                epsilon_d = app.AdiabaticInletEfficiencylowspeedEditField.Value;

                if M_0 >= 7
                    epsilon_d = app.AdiabaticInletEfficiencyhighspeedEditField.Value;
                end

                %epsilon_spil = 1;
                if M_0 < 4.5
                    epsilon_spil = 0.72;
                elseif M_0 < 5
                    epsilon_spil = 0.76;
                elseif M_0 < 5.5
                    epsilon_spil = 0.8;
                elseif M_0 < 6
                    epsilon_spil = 0.84;
                elseif M_0 < 6.5
                    epsilon_spil = 0.87;
                elseif M_0 < 7
                    epsilon_spil = 0.9;
                elseif M_0 < 7.5
                    epsilon_spil = 0.92;
                elseif M_0 < 8
                    epsilon_spil = 0.94;
                elseif M_0 == 8
                    epsilon_spil = 0.96;
                end

                % Inlet mass flow rate
                %mdot_0 = p0_0 * A_0/(R * T0_0) * (sqrt(gamma) * M_0/(1 + (gamma - 1)/2 * M_0^2)^((gamma + 1)/(2 * (gamma - 1)))); 
                mdot_0 = epsilon_spil * A_0 * u * ro_0;

                %%% PROCESSING %%%
                % Parameters after intake
                T0_2 = T0_0;
                p0_2 = epsilon_d * p0_0;
                % Cycle has been considere a total pressure constant cycle
                % because of low speed flow inside engine
                T_2 = T0_2;
                p_2 = p0_2;
                p_4 = p_2; 
                p0_4 = p_4;
                p0_9 = p0_4;

                % Fuel ratio (temperature after combustion variation)
                %f = f_st;

        %         % Parameters after combustor
        %         if M_0 < 5
        %             T_4 = 2698.49;
        %         elseif M_0 <= 7
        %             T_4 = 2563.33;
        %         elseif M_0 <= 8
        %             T_4 = 2467.94;
        %         end

                T_4 = T_Z22;

                %T_4 = T_2 + eta_b*f*(H_i/c_p1);
                p0_3 = epsilon_b * p0_2;
                p_3 = p_4;

                %Fuel ratio (temperature after combustion data)
                f = (c_p1 * (T_4 - T_2)) / (eta_b * H_i - c_p1 * (T_4 - T_2));
                if f < 0.025
                    f = app.AirfuelratioEditField_2.Value;
                end
                % Air-fuel ratio
                alpha = 1/f;

                % Propellant mass flow rate
                mdot_b = mdot_0 * f;

                % Adapted nozzle 
                p_9 = p_0;
                T_9 = T_4 * (p_9/p_4)^((gamma1-1)/gamma1);

                u_9 = M_0 * sqrt(gamma1*R*T_9);
                % Finding exit mach flow

                M_x = 0.5;
                for M_x=0:0.01:8
                    %sol = (M_x *((gamma1+1)/2)^((gamma1+1)/(2*(gamma1-1))))/((1 + (gamma1-1)/2 * M_x^2)^((gamma1+1)/(2*(gamma1-1))));
                    sol = 1/M_x * ((1 + (gamma1-1)/2 * M_x^2)/((gamma1 + 1)/2))^((gamma1+1)/(2*(gamma1-1)));
                    geom = A_e1/A_t;
                    if abs(sol - geom)<=0.1
                        M_e1 = M_x;
                    end
                end

                M_x = M_e1;
                for M_x=M_e1:0.01:8
                    %sol = (M_x *((gamma1+1)/2)^((gamma1+1)/(2*(gamma1-1))))/((1 + (gamma1-1)/2 * M_x^2)^((gamma1+1)/(2*(gamma1-1))));
                    sol = M_e1/M_x * ((1 + (gamma1-1)/2 * M_x^2)^((gamma1+1)/(2*(gamma1-1)))/(1 + (gamma1-1)/2 * M_e1^2)^((gamma1+1)/(2*(gamma1-1))));
                    geom = A_e2/A_e1;
                    if abs(sol - geom)<=0.1
                        M_e = M_x;
                    end
                end

                T_e = T_4/(1 + (gamma1-1)/2 * M_e);
                %p_e_id = (p_0 * (1+(gamma - 1)/2 * M_0^(2))^(gamma/(gamma - 1)))/(1+(gamma1 - 1)/2 * M_e^(2))^(gamma1/(gamma1 - 1));
                %p_e = p_e_id * epsilon_n * eta_b * epsilon_d;
                p_e = p_0;

                % Outflow rate
                w_e = M_e * sqrt(gamma1*R*T_e);       

                 %%% Thrust
                %T = (mdot_0 + mdot_b) * w_e - mdot_0 * u + A_e2 * (p_e - p_0);
                T = 0.6 * (mdot_0 + mdot_b) * w_e - 0.6 * mdot_0 * u;

                %%% Specific Thrust
                %I_a = (1 + f) * w_e - u;
                I_a = T / mdot_0;

                %%% Thermal Efficiency
                %eta_th = 1 - 1 / (1 + (gamma - 1)/2 * M_0^2);
                %%% Propulsive Efficiency
                %eta_p = 2 / (sqrt(T0_3 / (T_0 * (1 + (gamma - 1)/2 * M_0^2))) + 1);

                %%% Thrust Specific Fuel Consumption
                %I_sp = (I_a + 2 * u) / (2 * eta_th * H_i);
                I_sp = mdot_b / T;

                T_4_z(w,i) = T_4;
                T_z(w,i) = T;
                I_a_z(w,i) = I_a;
                I_sp_z(w,i) = I_sp;
                z_z(w,i) = z;

                i = i+1;
            end
            %T_old = T_z(w,1);
            w = w+1;
        end
        
        if strcmp(app.PlotDropDown_2.Value,'Thrust')
            cla(app.UIAxes2)
            for j=1:1:w-1
                plot(app.UIAxes2,z_z(j,:),T_z(j,:));
                hold(app.UIAxes2,'on'); 
            end
            title(app.UIAxes2,'Thrust');
            legend(app.UIAxes2,'M=4','M=4.5','M=5','M=5.5','M=6','M=6.5','M=7','M=7.5','M=8');
            xlabel(app.UIAxes2,'z [m]');
            ylabel(app.UIAxes2,'T [N]');
        elseif strcmp(app.PlotDropDown_2.Value,'SpecificThrust')
            cla(app.UIAxes2)
            for j=1:1:w-1
                plot(app.UIAxes2,z_z(j,:),I_a_z(j,:));
                hold(app.UIAxes2,'on');
            end
            title(app.UIAxes2,'Specific Thrust');
            legend(app.UIAxes2,'M=4','M=4.5','M=5','M=5.5','M=6','M=6.5','M=7','M=7.5','M=8');
            xlabel(app.UIAxes2,'z [m]');
            ylabel(app.UIAxes2,'I_a [N*s/kg]');                    
        elseif strcmp(app.PlotDropDown_2.Value,'TSFC')
            cla(app.UIAxes2)
            for j=1:1:w-1
                plot(app.UIAxes2,z_z(j,:),I_sp_z(j,:));
                hold(app.UIAxes2,'on');
            end
            title(app.UIAxes2,'TSFC');
            legend(app.UIAxes2,'M=4','M=4.5','M=5','M=5.5','M=6','M=6.5','M=7','M=7.5','M=8');
            xlabel(app.UIAxes2,'z [m]');
            ylabel(app.UIAxes2,'TSFC[kg/s/N]');                    
        end              
    end
end